@@ -106,28 +106,35 @@ function resolveURIInternal(aCmdLine, aArgument) {
   return uri;
 }
 
+const OVERRIDE_NONE        = 0;
+const OVERRIDE_NEW_PROFILE = 1;
+const OVERRIDE_NEW_MSTONE  = 2;
+/**
+ * Determines whether a home page override is needed.
+ * Returns:
+ *  OVERRIDE_NEW_PROFILE if this is the first run with a new profile.
+ *  OVERRIDE_NEW_MSTONE if this is the first run with a build with a different
+ *                      Gecko milestone (i.e. right after an upgrade).
+ *  OVERRIDE_NONE otherwise.
+ */
 function needHomepageOverride(prefb) {
-  var savedmstone;
+  var savedmstone = null;
   try {
     savedmstone = prefb.getCharPref("browser.startup.homepage_override.mstone");
-  }
-  catch (e) {
-  }
+  } catch (e) {}
 
   if (savedmstone == "ignore")
-    return 0;
+    return OVERRIDE_NONE;
 
   var mstone = Components.classes["@mozilla.org/network/protocol;1?name=http"]
                          .getService(nsIHttpProtocolHandler).misc;
 
   if (mstone != savedmstone) {
     prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
-    // Return 1 if true if the pref didn't exist (i.e. new profile) or 2 for an upgrade
-    return (savedmstone ? 2 : 1);
+    return (savedmstone ? OVERRIDE_NEW_MSTONE : OVERRIDE_NEW_PROFILE);
   }
-  
-  // Return 0 if not a new profile and not an upgrade
-  return 0;
+
+  return OVERRIDE_NONE;
 }
 
 // Copies a pref override file into the user's profile pref-override folder,
@@ -195,14 +202,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 203 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 213 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 210 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 220 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -215,7 +222,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 235 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 245 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -422,7 +429,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 454 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 464 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -435,43 +442,53 @@ var nsBrowserContentHandler = {
     var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
                               .getService(Components.interfaces.nsIURLFormatter);
 
-    var pagesToLoad = "";
-    var overrideState = needHomepageOverride(prefb);
+    var overridePage = "";
+    var haveUpdateSession = false;
     try {
-      if (overrideState == 1) {
-        // New profile.
-        pagesToLoad = formatter.formatURLPref("startup.homepage_welcome_url");
-      }
-      else if (overrideState == 2) {
-        // Existing profile.
-        copyPrefOverride();
+      switch (needHomepageOverride(prefb)) {
+        case OVERRIDE_NEW_PROFILE:
+          // New profile.
+          overridePage = formatter.formatURLPref("startup.homepage_welcome_url");
+          break;
+        case OVERRIDE_NEW_MSTONE:
+          // Existing profile.
+          copyPrefOverride();
 
-        pagesToLoad = formatter.formatURLPref("startup.homepage_override_url");
+          // Check whether we have a session to restore. If we do, we assume
+          // that this is an "update" session.
+          var ss = Components.classes["@mozilla.org/browser/sessionstartup;1"]
+                             .getService(Components.interfaces.nsISessionStartup);
+          haveUpdateSession = ss.doRestore();
+          overridePage = formatter.formatURLPref("startup.homepage_override_url");
+          break;
       }
-    }
-    catch (e) {
-    }
+    } catch (e) {}
 
-    var startpage = "";
+    // formatURLPref might return "about:blank" if getting the pref fails
+    if (overridePage == "about:blank")
+      overridePage = "";
+
+    var startPage = "";
     try {
       var choice = prefb.getIntPref("browser.startup.page");
       if (choice == 1)
-        startpage = this.startPage;
+        startPage = this.startPage;
 
       if (choice == 2)
-        startpage = Components.classes["@mozilla.org/browser/global-history;2"]
+        startPage = Components.classes["@mozilla.org/browser/global-history;2"]
                               .getService(nsIBrowserHistory).lastPageVisited;
-    }
-    catch (e) {
+    } catch (e) {
+      Components.utils.reportError(e);
     }
 
-    if (startpage == "about:blank")
-      startpage = "";
+    if (startPage == "about:blank")
+      startPage = "";
 
-    if (pagesToLoad && startpage) pagesToLoad += "|";
-    pagesToLoad += startpage;
-
-    return (pagesToLoad ?  pagesToLoad : "about:blank");
+    // Only show the startPage if we're not restoring an update session.
+    if (overridePage && startPage && !haveUpdateSession)
+      return overridePage + "|" + startPage;
+ 
+    return overridePage || startPage || "about:blank";
   },
 
   get startPage() {
@@ -613,13 +630,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 647 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 667 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 673 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 693 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -769,9 +786,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 823 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 843 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 825 "/usr/obj/ports/mozilla-firefox-2.0.0.3-debug/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 845 "/usr/obj/ports/mozilla-firefox-2.0.0.4-debug/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
